pub fn parse(content: &str, session_name: &str) -> Result<CodexSession>Expand description
Parse one Codex JSONL session file.
Errors
Returns an error when the JSONL cannot be parsed or required session metadata is missing.
pub fn parse(content: &str, session_name: &str) -> Result<CodexSession>Parse one Codex JSONL session file.
Returns an error when the JSONL cannot be parsed or required session metadata is missing.