pub(crate) fn parse_preview(
reader: impl BufRead,
session_name: &str,
) -> Result<CodexSession>Expand description
Parse the metadata and first user prompt from a Codex session reader.
Stops once the list preview is complete or the session is a subagent.